/********************************************************************
 * @file    missing.c
 * @brief   Replacements for when certain functions are missing.
 * @author  $LastChangedBy: rcraven $ (hiccups@cmand.org)
 * @version $LastChangedRevision: 496 $
 * @date    $Date: 2014-04-17 19:23:40 -0700 (Thu, 17 Apr 2014) $
 *
 * $Id: missing.c 496 2014-04-18 02:23:40Z rcraven $
 ********************************************************************/
#include "hiccups.h"

#ifndef HAVE_STRSEP
/* Copyright (C) 2004 Free Software Foundation, Inc. */
char* strsep(char **stringp, const char *delim)
{
   char *start = *stringp;
   char *ptr;

   if (!start)
       return NULL;

   if (!*delim)
       ptr = start + strlen(start);
   else {
       ptr = strpbrk(start, delim);
       if (!ptr) {
           *stringp = NULL;
           return start;
       }
   }

   *ptr = '\0';
   *stringp = ptr + 1;

   return start;
}
#endif /* HAVE_STRSEP */

#ifndef HAVE_INET_ATON
int inet_aton(const char *ipstr, struct in_addr *out)
{
    out->s_addr = inet_addr(ipstr);
    return 0;
}
#endif /* HAVE_INET_ATON */

/*
#if HAVE_MALLOC == 0
* Allocate an N-byte block of memory from the heap.  If N is zero, allocate a 1-byte block.  *
void *rpl_malloc(size_t n)
{
    if (n == 0)
        n = 1;
    return malloc(n);
}
#endif * HAVE_MALLOC *

#if HAVE_REALLOC == 0
* AC_FUNC_REALLOC in configure defines realloc to rpl_realloc if
   realloc(0,0) is NULL to make it GNU compatible and always return a
   valid pointer, same for AC_FUNC_MALLOC, malloc, and rpl_malloc.
   rpl means `replacement'.

   If this ever turns out to be a problem, it might be easiest to just
   kill the configure macro calls.
 *
void *rpl_realloc(void *p, size_t n)
{
    if (n == 0)
        n = 1;
    if (p == 0)
        return malloc (n);
  return realloc (p, n);
}
#endif * HAVE_REALLOC *
*/

